<?php
/**
 * @author Takács Ákos (Rimelek), programmer [at] rimelek [dot] hu
 * @copyright Copyright (C) 2009, Takács Ákos
 * @package REPHPGraph
 */

/**
 * Ellipszis iterátor importálása
 */
require_once dirname(__FILE__).'/EllipseIterator.class.php';

/**
 * MultiEllipseIterator
 * 
 * Egyszerre több ellipszis koordinátáit képes generálni
 * különböző középpont koordinátákkal, szélességgel és magassággal. 
 *
 * @author Takács Ákos (Rimelek), programmer [at] rimelek [dot] hu
 * @copyright Copyright (C) 2009, Takács Ákos
 * @version 1.0
 * @package REPHPGraph
 */
class MultiEllipseIterator extends EllipseIterator
{
	
	/**
	 * Iterátor centrumainak X koordinátái
	 * 
	 * @var array
	 */
	protected $cx = array();
	/**
	 * Iterátor centrumainak Y koordinátái
	 * 
	 * @var array
	 */
	protected $cy = array();
	/**
	 * Elipszisek magassága
	 * @var array
	 */
	protected $height = array();
	/**
	 * Elipszisek szélessége
	 * @var array
	 */
	protected $width = array();

	
	/**
	* MultiEllipseIterator konstruktor
	* 
	* Csak értékeket állít be, amit majd az iterációkor használ  
	* 
	* @param array $cx Elipszis centrumainak X koordinátái
	* @param array $cy Elipszis centrumainak Y koordinátái
	* @param array $width Elipszisek szélessége
	* @param array $height Elipszisek magassága
	*/
	function __construct($cx,$cy,$width,$height)
	{      ;
		parent::__construct($cx,$cy,$width,$height);
	}
	
	/**
	* Tulajdonságok értékeinek lekérdezésekor lefutó metódus
	* 
	* @param string $var
	* @return mixed
	*/
	function __get($var) 
	{	
		return parent::__get($var);
	}
	
	/**
	* Tulajdonságok értékeinek beállításakor lefutó metódus
	* 
	* @param string $var
	* @param mixed $value
	*/
	function __set($var,$value)
	{
		parent::__set($var,$value);
	}
	/**
	 * Aktuális iterált értékek
	 *
	 * @return array
	 */
	public function current() 
	{ 
		$x=array();
		$y=array();
		foreach ($this->cx as $key => $value) { 
			$x[$key] = $this->cx[$key] + (cos(deg2rad($this->_i)) * ceil($this->width[$key] / 2));
			$y[$key] = $this->cy[$key] + (sin(deg2rad($this->_i)) * ceil($this->height[$key] / 2)); 
		}
		return array('x'=>$x,'y'=>$y);
	}
	
	/**
	 * Konkrét elem visszaadása index alapján
	 * 
	 * @see EllipseIterator::offsetGet()
	 * 
	 * @param mixed $offset
	 * @return array
	 */
	public function offsetGet($offset) 
	{
		$x='';
		$y='';
		if ($this->offsetExists($offset)) {
			$i = $this->start+$offset*$this->add;
			foreach ($this->cx as $key => $value) { 
				$x[$key] = $this->cx[$key] + (cos(deg2rad($i)) * ceil($this->width[$key] / 2));
				$y[$key] = $this->cy[$key] + (sin(deg2rad($i)) * ceil($this->height[$key] / 2)); 
			}
		}
		return array('x'=>$x,'y'=>$y);
	}
	
}
?>