<?php
/**
 * @author Takács Ákos (Rimelek), programmer [at] rimelek [dot] hu
 * @copyright Copyright (C) 2008, Takács Ákos
 * @package REPHPGraph
 */

/**
 * Aobject importálása
 */
require_once dirname(__FILE__)."/../AObject.class.php";

/**
 * IObject importálása
 */
require_once dirname(__FILE__)."/../interfaces/IObject.class.php";


/**
 * Csillag alakzat
 * 
 * Akárhány ágú, és tetszőleges ághosszú szabályos csillagot hoz létre. 
 * Megadható ezeken kívül a csillag színe, a csillag szegélyének színe,
 * illetve hogy a csillag héttere látható legyen, vagy áttetsző, 
 * valamint a csillag sugara és az elforgatás szöge. 
 * De ez a funkció csak akkor működik, ha a kép típusát GIF-ként vagy PNG-ként definiáltuk. 
 * <br />
 * Egy egyszerű példa, mely 5 ágú, szabályos csillagot hoz létre. fehér színnel, és kék szegéllyel.
 * {@example ../examples/star.php} 
 * 
 * @version 1.0
 * @package REPHPGraph
 */
class Star extends AObject implements IObject
{
	/**
	 * Csillag sugara. Középtől a csúcsig
	 * @var int
	 */
	protected $radius = 80;
	/**	
	 * Ágak száma
	 * @var int
	 */
	protected $numPoint = 5;
	/**
	 * Ágak hossza
	 * @var int
	 */
	protected $lenPoint = 40;
	/**
	 * Az ősosztály __set() metódusában nem definiált értékadások
	 */
	function __set($var,$value) 
	{
		switch ($var)
		{
			case 'radius': case 'numPoint': case 'lenPoint': 
				$value = (int)$value;
				$this->$var = $value;
				break;                      
			default: parent::__set($var, $value);
		}        
	}
	/**
	 * Az ősosztály __get() metódusában még nem definiált változó lekérdezések
	 */
	function __get($var)
	{
		switch ($var)
		{
			case 'radius': case 'numPoint': case 'lenPoint': 
				return $this->$var;
				break;
			default: return parent::__get($var);
		}
	}       
	/**
	 * csillag példányosítása
	 * @param int $radius Csillag sugara
	 */
	function Star($radius)
	{
		//sugár beállítása, és abból a szélesség számítása
		$this->radius = $radius;
		$this->width = 2 * $radius;
		$this->height = 2 * $radius;
		//Kép létrehozása
		$this->source = imagecreatetruecolor($this->width,$this->height);

		//háttér és szín beállítása
		$this->backGround = imageColorAllocate($this->source,1,1,1);
		$this->color = imageColorAllocate($this->source,1,1,1);
		$this->borderColor = imageColorAllocate($this->source,1,1,1);
		
	}
	/**
	 * Létrehozza a csillag alakzatot
	 * 
	 * A már megadott tulajdonságok alapján létrehoz egy szabályos csillag alakzatot
	 */
	function create()
	{
		//Távolság a csillag közepe és a csócsai között
		$R2 = $this->radius;
		//Távolás a csillag közepe, és az ágak kezdete között
		$R1 = $this->radius - $this->lenPoint;
		//Ágak hossza
		$numPoint = $this->numPoint;
		//elforgatás szöge
		$angle = $this->angle;
		//csúcsok közti szögelfordulás kiszámítása
		$space = 360 / $numPoint;
		//koordináták tömbje
		$kulso_kor = array('X'=>array(),'Y'=>array());
		$belso_kor = array('X'=>array(),'Y'=>array());
		//egyező háttér és szegélyszín esetén új keretszín választása
		if ($this->borderColor == $this->backGround) {
			if ($this->borderColor == ($color = imagecolorAllocate($this->source,1,1,1))) {
				$this->borderColor = imageColorAllocate($this->source,0,0,0);
			} else {
				$this->borderColor = $color;
			}
		}
		$color = $this->borderColor; $szam=0;
		/* csúcspontok meghatározása :start:  */
		for($i=90+$angle;$i<=450+$angle; $i += $space) {
			$coord_x = ($this->width / 2) + (cos(deg2rad($i)) * $R1);
			$coord_y = ($this->height / 2)+(sin(deg2rad($i)) * $R1); 
			$belso_kor['X'][] = $coord_x;
			$belso_kor['Y'][] = $coord_y;
			imagesetpixel($this->source,$coord_x,$coord_y,$color); 
		}
		
		$szam=0;
		for($i=($space/2)+90+$angle;$i<=(360+(3*$space)/2)+90+$angle; $i += $space) {
			$coord_x = ($this->width / 2) + (cos(deg2rad($i)) * $R2);
			$coord_y = ($this->height / 2)+(sin(deg2rad($i)) * $R2); 
			$kulso_kor['X'][] = $coord_x;
			$kulso_kor['Y'][] = $coord_y;
			imagesetpixel($this->source,$coord_x,$coord_y,$color);
		} 
		/* csúcspontok meghatározása :end: */
                
		$maxIndex = count($belso_kor['X'])-1; 
		//csúcspontok összekötése
		for($i=0; $i<=$maxIndex; $i++) {
			imageline($this->source,$belso_kor['X'][$i],$belso_kor['Y'][$i],$kulso_kor['X'][$i],$kulso_kor['Y'][$i],$color);
			if ($i >0) {
				imageline($this->source,$belso_kor['X'][$i],$belso_kor['Y'][$i],$kulso_kor['X'][$i-1],$kulso_kor['Y'][$i-1],$color);
			}
		}
		imageline($this->source,$belso_kor['X'][0],$belso_kor['Y'][0],$kulso_kor['X'][$maxIndex],$kulso_kor['Y'][$maxIndex],$color);
		//Szín kitöltés
		imagefill($this->source,ceil($this->width / 2),ceil($this->height / 2),$this->color);		
	}
}
?>